==> cdap-cli-3.0.0-sources.jar: co/cask/cdap/cli/completer/element/AdapterIdCompleter.java <==
/*
 * Copyright © 2012-2014 Cask Data, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package co.cask.cdap.cli.completer.element;

import co.cask.cdap.cli.completer.StringsCompleter;
import co.cask.cdap.client.AdapterClient;
import co.cask.cdap.common.exception.UnauthorizedException;
import co.cask.cdap.proto.AdapterDetail;
import com.google.common.base.Supplier;
import com.google.common.collect.Lists;

import java.io.IOException;
import java.util.Collection;
import java.util.List;
import javax.inject.Inject;

/**
 * Completer for adapter IDs.
 */
public class AdapterIdCompleter extends StringsCompleter {

  @Inject
  public AdapterIdCompleter(final AdapterClient adapterClient) {
    super(new Supplier<Collection<String>>() {
      @Override
      public Collection<String> get() {
        try {
          List<AdapterDetail> list = adapterClient.list();
          List<String> ids = Lists.newArrayList();
          for (AdapterDetail item : list) {
            ids.add(item.getName());
          }
          return ids;
        } catch (IOException e) {
          return Lists.newArrayList();
        } catch (UnauthorizedException e) {
          return Lists.newArrayList();
        }
      }
    });
  }
}

==> cdap-cli-3.1.1-sources.jar: co/cask/cdap/cli/completer/element/AdapterIdCompleter.java <==
/*
 * Copyright © 2012-2014 Cask Data, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package co.cask.cdap.cli.completer.element;

import co.cask.cdap.cli.CLIConfig;
import co.cask.cdap.cli.completer.StringsCompleter;
import co.cask.cdap.client.AdapterClient;
import co.cask.cdap.common.UnauthorizedException;
import co.cask.cdap.proto.AdapterDetail;
import com.google.common.base.Supplier;
import com.google.common.collect.Lists;

import java.io.IOException;
import java.util.Collection;
import java.util.List;
import javax.inject.Inject;

/**
 * Completer for adapter IDs.
 */
public class AdapterIdCompleter extends StringsCompleter {

  @Inject
  public AdapterIdCompleter(final CLIConfig config, final AdapterClient adapterClient) {
    super(new Supplier<Collection<String>>() {
      @Override
      public Collection<String> get() {
        try {
          List<AdapterDetail> list = adapterClient.list(config.getCurrentNamespace());
          List<String> ids = Lists.newArrayList();
          for (AdapterDetail item : list) {
            ids.add(item.getName());
          }
          return ids;
        } catch (IOException e) {
          return Lists.newArrayList();
        } catch (UnauthorizedException e) {
          return Lists.newArrayList();
        }
      }
    });
  }
}
